@@ -1,11 +1,12 @@
 #!/bin/sh -e
 
 # called by uscan with '--upstream-version' <version> <file>
-DIR=jakarta-jmeter-$2
+DIR=apache-jmeter-$2
 TAR=../jakarta-jmeter_$2.orig.tar.gz
 
 # clean up the upstream tarball
 tar zxvf $3
+rm $3
 tar -c -z -f $TAR -X debian/orig-tar.exclude $DIR
 rm -rf $DIR
 
